==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/ru.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календарь",
    "Individual" : "Индивидуально",
    "Group" : "Группа",
    "Resource" : "Ресурс",
    "Room" : "Комната",
    "Unknown" : "Неизвестно",
    "Required" : "Требуется",
    "Optional" : "Не обязательно",
    "Does not attend" : "Без посещения",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Вы находитесь в неизвестном часовом поясе ({tz}), возвращаемся к UTC",
    "Please create a calendar first." : "Пожалуйста, создайте сначала календарь.",
    "New event" : "Новое событие",
    "Attendees" : "Участники",
    "Reminders" : "Напоминания",
    "Repeating" : "Повторение",
    "When shared show full event" : "Показывать подробное событие при размещении в общем доступе",
    "When shared show only busy" : "Показывать занятость при размещении в общем доступе",
    "When shared hide this event" : "Скрыть это событие при размещении в общем доступе",
    "Please add a title!" : "Пожалуйста добавьте заголовок!",
    "Please select a calendar!" : "Пожалуйста выберите календарь!",
    "Global" : "Основные",
    "None" : "Отсутствует",
    "Every day" : "Каждый день",
    "Every week" : "Каждую неделю",
    "Every month" : "Каждый месяц",
    "Every year" : "Каждый год",
    "never" : "никогда",
    "after" : "после",
    "At time of event" : "Время события",
    "5 minutes before" : "За 5 минут до начала",
    "10 minutes before" : "За 10 минут до начала",
    "15 minutes before" : "За 15 минут до начала",
    "30 minutes before" : "За 30 минут до начала",
    "1 hour before" : "За 1 час до начала",
    "2 hours before" : "За 2 часа до начала",
    "Custom" : "Произвольно",
    "Audio" : "Аудио",
    "E Mail" : "E Mail",
    "Pop up" : "Всплывающее окно",
    "sec" : "сек",
    "min" : "мин",
    "hours" : "часов",
    "days" : "дней",
    "week" : "неделя",
    "before" : "прежде",
    "start" : "начало",
    "end" : "конец",
    "Editing reminders of unknown type not supported." : "Редактирование напоминаний неизвестного типа не поддерживается.",
    "Week {number} of {year}" : "{number} неделя {year} года",
    "Successfully imported" : "Успешно импортировано",
    "Partially imported, 1 failure" : "Частично импортировано, 1 ошибка",
    "Partially imported, {n} failures" : "Частично импортировано, {n} ошибок",
    "Audio alarm" : "Звуковой сигнал",
    "Pop-up" : "Всплывающее окно",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} до начала события",
    "{type} {time} before the event ends" : "{type} {time} до окончания события",
    "{type} {time} after the event starts" : "{type} {time} после начала события",
    "{type} {time} after the event ends" : "{type} {time} после окончания события",
    "{type} at the event's start" : "{type} в момент начала события",
    "{type} at the event's end" : "{type} в момент окончания события",
    "{type} at {time}" : "{type} в {time}",
    "{calendar} shared by {owner}" : "{calendar} опубликован пользователем {owner}",
    "Title of the Event" : "Название события",
    "starts" : "начинается",
    "ends" : "заканчивается",
    "All day Event" : "Событие на весь день",
    "Delete" : "Удалить",
    "Cancel" : "Отмена",
    "More ..." : "Больше ...",
    "Create" : "Создать",
    "Update" : "Обновить",
    "Close" : "Закрыть",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Export" : "Экспорт",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Из-за предшествующей ошибки, календарь в настоящее время не в состоянии обеспечить поддержку функции файлопровода.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Пожалуйста свяжитесь с администратором и попросите отключить опцию \"assep-pipeline.enabled\"",
    "Day" : "День",
    "Week" : "Неделя",
    "Month" : "Месяц",
    "Today" : "Сегодня",
    "Share Calendar" : "Поделиться календарем",
    "More" : "Больше",
    "Edit" : "Редактировать",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "Общий доступ с пользователями или группами",
    "can edit" : "можно редактировать",
    "group" : "группа",
    "New Calendar" : "Новый Календарь",
    "Subscriptions" : "Подписки",
    "New Subscription" : "Новая подписка",
    "Url" : "Url",
    "Edit event" : "Редактировать событие",
    "Delete Event" : "Удалить событие",
    "Save Event" : "Сохранить событие",
    "Time" : "Время",
    "Type" : "Тип",
    "Relative" : "Относительное",
    "Absolute" : "Абсолютное",
    "Repeat" : "Повтор",
    "times every" : "раз каждые",
    "Add" : "Добавить",
    "E-Mail address of attendee" : "Адрес электронной почты участника",
    "Please add your email address in the personal settings in order to add attendees." : "Пожалуйста, добавьте свой адрес электронной почты в личных настройках, чтобы добавить участников.",
    "from" : "из",
    "to" : "до",
    "This event's repeating rule is not supported yet." : "Повторяющееся правило этого события пока не поддерживается.",
    "Support for advanced rules will be added with subsequent updates." : "Поддержка расширенных правил будут добавлены с последующими обновлениями.",
    "Reset repeating rule" : "Сбросить правила повтора",
    "Repeat every ..." : "Повторять каждые ...",
    "end repeat ..." : "конец повтора ...",
    "times" : "раз",
    "Import Calendars" : "Импорт календарей",
    "Import canceled" : "Импорт отменён",
    "Analyzing calendar" : "Анализ календарей",
    "The file contains objects incompatible with the selected calendar" : "Файл содержит объекты, которые не совместимы с выбранным календарем",
    "New calendar" : "Новый календарь",
    "Import scheduled" : "Импорт запланирован",
    "Settings" : "Настройки",
    "Import calendar" : "Импорт календаря",
    "No Calendars selected for import" : "Календари для импорта не выбраны",
    "Primary CalDAV address" : "Основной адрес синхронизации CalDAV",
    "iOS/OS X CalDAV address" : "Адрес синхронизации iOS/OS X CalDAV"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-app-calendar-1%3A1.3.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/ru.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календарь",
    "Individual" : "Индивидуально",
    "Group" : "Группа",
    "Resource" : "Ресурс",
    "Room" : "Комната",
    "Unknown" : "Неизвестно",
    "Required" : "Требуется",
    "Optional" : "Не обязательно",
    "Does not attend" : "Без посещения",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Вы находитесь в неизвестном часовом поясе ({tz}), возвращаемся к UTC",
    "Please create a calendar first." : "Пожалуйста, создайте сначала календарь.",
    "New event" : "Новое событие",
    "Attendees" : "Участники",
    "Reminders" : "Напоминания",
    "Repeating" : "Повторение",
    "When shared show full event" : "Показывать подробное событие при размещении в общем доступе",
    "When shared show only busy" : "Показывать занятость при размещении в общем доступе",
    "When shared hide this event" : "Скрыть это событие при размещении в общем доступе",
    "Confirmed" : "Подтверждено",
    "Tentative" : "Возможно",
    "Cancelled" : "Отменено",
    "Please add a title!" : "Пожалуйста добавьте заголовок!",
    "Please select a calendar!" : "Пожалуйста выберите календарь!",
    "Global" : "Основные",
    "None" : "Отсутствует",
    "Every day" : "Каждый день",
    "Every week" : "Каждую неделю",
    "Every month" : "Каждый месяц",
    "Every year" : "Каждый год",
    "never" : "никогда",
    "after" : "после",
    "At time of event" : "Время события",
    "5 minutes before" : "За 5 минут до начала",
    "10 minutes before" : "За 10 минут до начала",
    "15 minutes before" : "За 15 минут до начала",
    "30 minutes before" : "За 30 минут до начала",
    "1 hour before" : "За 1 час до начала",
    "2 hours before" : "За 2 часа до начала",
    "Custom" : "Произвольно",
    "Audio" : "Аудио",
    "E Mail" : "E Mail",
    "Pop up" : "Всплывающее окно",
    "sec" : "сек",
    "min" : "мин",
    "hours" : "часов",
    "days" : "дней",
    "week" : "неделя",
    "before" : "прежде",
    "start" : "начало",
    "end" : "конец",
    "Editing reminders of unknown type not supported." : "Редактирование напоминаний неизвестного типа не поддерживается.",
    "Week {number} of {year}" : "{number} неделя {year} года",
    "Successfully imported" : "Успешно импортировано",
    "Partially imported, 1 failure" : "Частично импортировано, 1 ошибка",
    "Partially imported, {n} failures" : "Частично импортировано, {n} ошибок",
    "Audio alarm" : "Звуковой сигнал",
    "Pop-up" : "Всплывающее окно",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} до начала события",
    "{type} {time} before the event ends" : "{type} {time} до окончания события",
    "{type} {time} after the event starts" : "{type} {time} после начала события",
    "{type} {time} after the event ends" : "{type} {time} после окончания события",
    "{type} at the event's start" : "{type} в момент начала события",
    "{type} at the event's end" : "{type} в момент окончания события",
    "{type} at {time}" : "{type} в {time}",
    "{calendar} shared by {owner}" : "{calendar} опубликован пользователем {owner}",
    "Title of the Event" : "Название события",
    "starts" : "начинается",
    "ends" : "заканчивается",
    "All day Event" : "Событие на весь день",
    "Delete" : "Удалить",
    "Cancel" : "Отмена",
    "More ..." : "Больше ...",
    "Create" : "Создать",
    "Update" : "Обновить",
    "Close" : "Закрыть",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Event status" : "Статус события",
    "Visibility when sharing" : "Видимость при общем доступе",
    "Export" : "Экспорт",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Из-за предшествующей ошибки, календарь в настоящее время не в состоянии обеспечить поддержку функции файлопровода.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Пожалуйста свяжитесь с администратором и попросите отключить опцию \"assep-pipeline.enabled\"",
    "Day" : "День",
    "Week" : "Неделя",
    "Month" : "Месяц",
    "Today" : "Сегодня",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Некоторые события в этом календаре испорчены. Пожалуйста проверьте консоль JS для дополнительной информации.",
    "Share Calendar" : "Поделиться календарем",
    "Shared" : "Общий доступ",
    "More" : "Больше",
    "Edit" : "Редактировать",
    "Link" : "Ссылка",
    "Download" : "Скачать",
    "Share with users or groups" : "Общий доступ с пользователями или группами",
    "can edit" : "можно редактировать",
    "group" : "группа",
    "New Calendar" : "Новый Календарь",
    "Subscriptions" : "Подписки",
    "New Subscription" : "Новая подписка",
    "Url" : "Url",
    "Edit event" : "Редактировать событие",
    "Delete Event" : "Удалить событие",
    "Save Event" : "Сохранить событие",
    "Time" : "Время",
    "Type" : "Тип",
    "Relative" : "Относительное",
    "Absolute" : "Абсолютное",
    "Repeat" : "Повтор",
    "times every" : "раз каждые",
    "Add" : "Добавить",
    "E-Mail address of attendee" : "Адрес электронной почты участника",
    "Please add your email address in the personal settings in order to add attendees." : "Пожалуйста, добавьте свой адрес электронной почты в личных настройках, чтобы добавить участников.",
    "from" : "из",
    "to" : "до",
    "This event's repeating rule is not supported yet." : "Повторяющееся правило этого события пока не поддерживается.",
    "Support for advanced rules will be added with subsequent updates." : "Поддержка расширенных правил будут добавлены с последующими обновлениями.",
    "Reset repeating rule" : "Сбросить правила повтора",
    "Repeat every ..." : "Повторять каждые ...",
    "end repeat ..." : "конец повтора ...",
    "times" : "раз",
    "Import Calendars" : "Импорт календарей",
    "Import canceled" : "Импорт отменён",
    "Analyzing calendar" : "Анализ календарей",
    "The file contains objects incompatible with the selected calendar" : "Файл содержит объекты, которые не совместимы с выбранным календарем",
    "New calendar" : "Новый календарь",
    "Import scheduled" : "Импорт запланирован",
    "Settings" : "Настройки",
    "Skip simple event editor" : "Пропустить простой редактор события",
    "Import calendar" : "Импорт календаря",
    "No Calendars selected for import" : "Календари для импорта не выбраны",
    "Primary CalDAV address" : "Основной адрес синхронизации CalDAV",
    "iOS/OS X CalDAV address" : "Адрес синхронизации iOS/OS X CalDAV"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
